========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - dependencies
      - | |pyver| |requires|
    * - ci-status
      - | |travis| |readthedocs|
    * - releases
      - | |version| |commits-since|
    * - packages
      - | |conda-platforms|

.. |pyver| image:: https://img.shields.io/badge/python-3.6+-blue.svg
    :alt: Requires Python 3.6+
    :target: https://www.python.org/getit

.. |travis| image:: https://travis-ci.org/plstcharles/thelper.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/plstcharles/thelper

.. |commits-since| image:: https://img.shields.io/github/commits-since/plstcharles/thelper/v0.2.8.svg
    :alt: Commits since latest release
    :target: https://github.com/plstcharles/thelper/compare/v0.2.8...master

.. |readthedocs| image:: https://readthedocs.org/projects/thelper/badge/?version=latest
    :alt: Documentation Build Status
    :target: https://thelper.readthedocs.io/en/latest/?badge=latest

.. |version| image:: https://img.shields.io/pypi/v/thelper.svg
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/thelper

.. |requires| image:: https://requires.io/github/plstcharles/thelper/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/plstcharles/thelper/requirements/?branch=master

.. |conda-platforms| image:: https://anaconda.org/plstcharles/thelper/badges/platforms.svg
    :alt: Platform Build Status
    :target: https://anaconda.org/plstcharles/thelper

.. end-badges

This package provides a training framework and CLI for PyTorch-based machine learning projects. This is free
software distributed under the `Apache Software License version 2.0`__ built by researchers and developers
from the Centre de Recherche Informatique de Montréal / Computer Research Institute of Montreal (CRIM).

.. __: <https://tldrlegal.com/license/apache-license-2.0-(apache-2.0)>

To get a general idea of what this framework can be used for, visit the `FAQ page
<https://thelper.readthedocs.io/en/latest/faq.html>`_. For installation instructions, refer to the
`installation guide <https://github.com/plstcharles/thelper/blob/master/INSTALL.rst>`_. For usage instructions,
refer to the `user guide <https://thelper.readthedocs.io/en/latest/user-guide.html>`_. The auto-generated
documentation is available via `readthedocs.io <https://thelper.readthedocs.io/en/latest/>`_.


Notes
-----

Development is still on-going --- the API and internal classes may change in the future.

The project's structure was originally generated by `cookiecutter <https://github.com/audreyr/cookiecutter>`_
via `ionelmc's template <https://github.com/ionelmc/cookiecutter-pylibrary>`_.
